/**
 *
 * @description Generates a unique identifier (UID) for a LinkedIn Badge component. It ensures that the ID does not clash with any existing IDs. To achieve this, the method uses a set of criteria such as the component's properties, hostname, pathname, search, IP address, and current timestamp. In contrast, LinkedIn uses a random number, which may result in collisions. The proposed method offers a more reliable and robust solution for UID generation. It does not rely on cryptographic algorithms or libraries that are not necessary for the context of UID usages. The UID mainly serves as unique DOM identifiers.
 * @param {Record<string, any>} props - The properties of the LinkedIn Badge component.
 * @param {boolean} [generateUidWithoutApi] - Defaults as false. If true, the UID creation won't include utilizing an API call to form a more unique UID.
 * @returns {Promise<string>} The generated UID, which is an unsigned 32-bit integer in string format.
 */
export declare function generateUidFromProps(props: Record<string, any>, generateUidWithoutApi?: boolean): Promise<string>;
//# sourceMappingURL=index.d.ts.map